/*
 * Copyright (c) 2008 Lukas Mejdrech
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - The name of the author may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/** @addtogroup net
 *  @{
 */

/** @file
 */

#ifndef __NET_PACKET_CLIENT_H__
#define __NET_PACKET_CLIENT_H__

#include "packet.h"

#define PACKET_PREPEND( packet, type )	( type * ) packet_prepend(( packet ), sizeof( type ))
#define PACKET_APPEND( packet, type )	( type * ) packet_append(( packet ), sizeof( type ))
#define PACKET_TRIM( packet, prefix, sufix )	packet_trim(( packet ), sizeof( prefix ), sizeof( sufix ))

void *	packet_prepend( packet_t packet, size_t length );
void *	packet_append( packet_t packet, size_t length );
packet_t	packet_copy( int phone, services_t owner, const packet_t packet );
int	packet_copy_data( packet_t packet, const void * data, size_t length );
int	packet_trim( packet_t packet, size_t prefix, size_t sufix );
int	packet_destroy( packet_t packet );
packet_id_t packet_get_id( packet_t packet );
size_t	packet_get_data_length( const packet_t packet );
void *	packet_get_data( const packet_t packet );
int	packet_get_addr( const packet_t packet, uint8_t ** src, uint8_t ** dest );
packet_mode_t	packet_get_mode( const packet_t packet );
int	packet_set_addr( packet_t packet, const uint8_t * src, const uint8_t * dest, size_t addr_len );
int	packet_set_mode( packet_t packet, packet_mode_t mode );
int	packet_set_owner( packet_t packet, services_t owner );

int packet_translate( int phone, packet_ref packet, packet_id_t packet_id );
packet_t packet_get_5( int phone, services_t owner, size_t max_content, size_t addr_len, size_t max_prefix, size_t max_sufix );
packet_t packet_get_1( int phone, services_t owner, size_t content );
void packet_release( int phone, packet_id_t packet_id );

#endif

/** @}
 */
